California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 80 - ELECTRIC SERVICE PROVIDERS. REGULATION. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1273998 | ALLIANCE FOR A BETTER CALIFORNIA, EDUCATORS, FIREFIGHTERS, SCHOOL EMPLOYEES, HEALTH CARE GIVERS AND LABOR ORGANIZATIONS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1280140 | CALIFORNIANS AGAINST ARNOLD'S SPECIAL INTEREST ELECTION - NO ON 73, 74, 75, 76, 77 AND 78 AND YES ON 79 AND 80, SPONSORED BY WORKING ASSETS AND BALLOT INITIATIVE STRATEGY CENTER | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1279272 | YES ON 80 - LIGHTS ON CALIFORNIA, A COALITION OF CONSUMER GROUPS AND LABOR UNIONS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1277887 | CALIFORNIANS FOR RELIABLE ELECTRICITY - NO ON 80 - ENERGY & MANUFACTURERS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1278055 | MORE POWER THROUGH CHOICE - NO ON PROPOSITION 80, SPONSORED BY ALLIANCE FOR RETAIL MARKETS | OPPOSE